#######################################################################
#
# anim.py - Animation Data.
#
# This module contains a bunch of data used by pyrunner.py to help it
# determine how to animate objects.
#
# PyRunner 0.2 (beta) - July 9th, 2003
# Copyright 2003 Ketche
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA
#
#######################################################################

# PyRunner imports.
from const import *

# =====================================================================

# Animation Data.

# Assign a direction for each action.  This tells the animator which
# way to incrementally move a sprite.
dirdict = {ACTIONSTILL: DIRNONE, ACTIONLEFT: DIRLEFT,
           ACTIONRIGHT: DIRRIGHT, ACTIONUP: DIRUP,
           ACTIONDOWN: DIRDOWN, ACTIONDIGLEFT: DIRNONE,
           ACTIONDIGRIGHT: DIRNONE, ACTIONSWINGLEFT: DIRLEFT,
           ACTIONSWINGRIGHT: DIRRIGHT, ACTIONFALL: DIRDOWN,
           ACTIONDEATH: DIRNONE, ACTIONSWITCHLEFT: DIRLEFT,
           ACTIONSWITCHRIGHT: DIRRIGHT }

# This dictionary defines our animation sequences for the player.
## Could reduce clutter by moving the animations to one file and
## defining a list of source regions instead.
playerfiles = { \
    ACTIONSTILL: \
        ("player.bmp", "player.bmp", "player.bmp", "player.bmp"),
    ACTIONLEFT: \
        ("player_l1.bmp", "player_l1.bmp", "player_l1.bmp", "player_l1.bmp"),
    ACTIONRIGHT: \
        ("player_r1.bmp", "player_r1.bmp", "player_r1.bmp", "player_r1.bmp"),
    ACTIONUP: \
        ("playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp"),
    ACTIONDOWN: \
        ("playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp"),
    ACTIONDIGLEFT: \
        ("player_l2.bmp", "player_l2.bmp", "player_l2.bmp", "player_l2.bmp"),
    ACTIONDIGRIGHT: \
        ("player_r2.bmp", "player_r2.bmp", "player_r2.bmp", "player_r2.bmp"),
    ACTIONSWINGLEFT: \
        ("playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp"),
    ACTIONSWINGRIGHT: \
        ("playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp", "playerclimb1.bmp"),
    ACTIONFALL: \
        ("playerfall.bmp", "playerfall.bmp", "playerfall.bmp", "playerfall.bmp"),
    ACTIONDEATH: \
        ("playerfall.bmp", "playerfall.bmp", "playerfall.bmp", "playerfall.bmp"),
    ACTIONSWITCHLEFT: \
        ("player_l1.bmp", "player_l1.bmp", "player_l1.bmp", "player_l2.bmp"),
    ACTIONSWITCHRIGHT: \
        ("player.bmp", "player.bmp", "player.bmp", "player.bmp") }

# Same as playerfiles, but these are for the enemy.
enemyfiles = { \
    ACTIONSTILL: \
        ("enemy.bmp", "enemy.bmp", "enemy.bmp", "enemy.bmp"),
    ACTIONLEFT: \
        ("enemy_l1.bmp", "enemy_l1.bmp", "enemy_l1.bmp", "enemy_l1.bmp"),
    ACTIONRIGHT: \
        ("enemy_r1.bmp", "enemy_r1.bmp", "enemy_r1.bmp", "enemy_r1.bmp"),
    ACTIONUP: \
        ("enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp"),
    ACTIONDOWN: \
        ("enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp"),
    ACTIONDIGLEFT: \
        ("enemy_l1.bmp", "enemy_l1.bmp", "enemy_l1.bmp", "enemy_l1.bmp"),
    ACTIONDIGRIGHT: \
        ("enemy_r1.bmp", "enemy_r1.bmp", "enemy_r1.bmp", "enemy_r1.bmp"),
    ACTIONSWINGLEFT: \
        ("enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp"),
    ACTIONSWINGRIGHT: \
        ("enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp"),
    ACTIONFALL: \
        ("enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp", "enemyclimb1.bmp"),
    ACTIONDEATH: \
        ("enemydeath.bmp", "enemydeath.bmp", "enemydeath.bmp", "enemydeath.bmp"),
    ACTIONSWITCHLEFT: \
        ("enemy.bmp", "enemy.bmp", "enemy.bmp", "enemy.bmp"),
    ACTIONSWITCHRIGHT: \
        ("enemy.bmp", "enemy.bmp", "enemy.bmp", "enemy.bmp")}
