from const import *
import os.path

class Map:
    symbols = {'.': EMPTY, '#': FLOOR, '%': PERMFLOOR, '=': LADDER,
               '-': BAR, '|': POLE, '$': TREASURE, '<': GATELEFT,
               '>': GATERIGHT, '/': SWITCH, '^': SPIKES, '0': EXITPOINT}
    specialsymbols = {'@': PLAYERSTART, '!': ENEMYSTART,
                      '?': ENEMYREGEN}
    falsesymbols = {'+': FLOOR, '*': PERMFLOOR, '"': LADDER,
                    "'": BAR, ':': POLE, '&': SPIKES, '_': EXITPOINT,
                    '~': TREASURE, '\\': SWITCH}
    aftersymbols1 = {'F': FLOOR, 'M': PERMFLOOR, 'L': LADDER,
               'S': BAR, 'P': POLE, 'T': TREASURE, '[': GATELEFT,
               ']': GATERIGHT, 'W': SWITCH, 'K': SPIKES,
               'E': ENEMYSTART, 'R': ENEMYREGEN, 'X': EXITPOINT}
    aftersymbols2 = {'f': FLOOR, 'm': PERMFLOOR, 'l': LADDER,
               's': BAR, 'p': POLE, 't': TREASURE, '(': GATELEFT,
               ')': GATERIGHT, 'w': SWITCH, 'k': SPIKES,
               'e': ENEMYSTART, 'r': ENEMYREGEN, 'x': EXITPOINT}
    aftersymbols = (aftersymbols1, aftersymbols2)
    def __init__(self, mapfile = None):
        self.data = []
        self.playerstart = ()
        self.enemystart = []
        self.enemyregen = []
        self.exits = []
        self.false = []
        self.after = [[], []]
        self.hints = []
        self.collectall = 1
        self.numstages = 1
        self.exitattop = 1
        self.flipgatesatend = 0
        self.artwork = "default"
        self.treasureleft = 0
        self.gates = []
        self.stage = 0
        tmp = []
        for i in range(MAPWIDTH):
            tmp.append(EMPTY)
        for i in range(MAPHEIGHT):
            self.data.append(list(tmp))   # Make a copy of tmp each time
        if mapfile:
            self.initfromfile(mapfile)

    def initfromfile(self, filename):
        def istrue(str):
            truenames = ("true", "1", "on", "yes")
            return str.lower() in truenames
        maprow = 0
        f = open(filename, "r")
        #Err
        while 1:
            str = f.readline()
            if str == "":           # Test for end of file
                break
            if str[0] == ';':       # Ignore comments
                continue
            if str[-1] == '\n':     # Strip newline
                str = str[:-1]
            if str.strip() == "":   # Ignore blank lines
                continue
            tmp = str.split(None, 1)
            if len(tmp) != 2:
                # Err
                continue
            keyword = tmp[0].lower()
            options = tmp[1]
            if keyword == "map":
                if maprow == MAPHEIGHT:
                    # Err
                    pass
                for mapcol in range(MAPWIDTH):
                    if mapcol == len(options):
                        break
                    if options[mapcol] in self.symbols.keys():
                        self.data[maprow][mapcol] = self.symbols[options[mapcol]]
                        if self.data[maprow][mapcol] == TREASURE:
                            self.treasureleft += 1
                        if self.data[maprow][mapcol] == GATELEFT or\
                           self.data[maprow][mapcol] == GATERIGHT:
                            self.gates.append((maprow, mapcol))
                        if self.data[maprow][mapcol] == EXITPOINT:
                            self.exits.append((maprow, mapcol))
                    elif options[mapcol] in self.specialsymbols.keys():
                        meaning = self.specialsymbols[options[mapcol]]
                        if meaning == PLAYERSTART:
                            if self.playerstart != ():
                                #Err only one playerstart allowed
                                pass
                            self.playerstart = (maprow, mapcol)
                        elif meaning == ENEMYSTART:
                            self.enemystart.append((maprow, mapcol))
                        elif meaning == ENEMYREGEN:
                            self.enemyregen.append((maprow, mapcol))
                        else:
                            #Err somehow the dict got screwed up
                            pass
                        self.data[maprow][mapcol] = EMPTY
                    elif options[mapcol] in self.falsesymbols.keys():
                        self.false.append((maprow, mapcol))
                        self.data[maprow][mapcol] = self.falsesymbols[options[mapcol]]
                    elif options[mapcol] in self.aftersymbols[0].keys():
                        self.after[0].append((maprow, mapcol, self.aftersymbols[0][options[mapcol]]))
                        self.data[maprow][mapcol] = EMPTY
                    elif options[mapcol] in self.aftersymbols[1].keys():
                        self.after[1].append((maprow, mapcol, self.aftersymbols[1][options[mapcol]]))
                        self.data[maprow][mapcol] = EMPTY
                    else:
                        #Err unknown symbol
                        pass
                maprow += 1
            elif keyword == "collectall":
                self.collectall = istrue(options)
            elif keyword == "numstages":
                self.numstages = int(options)
            elif keyword == "exitattop":
                self.exitattop = istrue(options)
            elif keyword == "flipgates":
                self.flipgatesatend = istrue(options)
            elif keyword == "horizwrap":
                self.horizwrap = istrue(options)
            elif keyword == "artwork":
                self.artwork = os.path.normpath(options)
            elif keyword == "hint":
                self.hints.append(options)
            else:
                # Err invalid keyword
                print keyword
                pass
        f.close()
