#######################################################################
#
# const.py - Global constants for use with all PyRunner modules.
#
# This module provides some program-wide constants.
#
# PyRunner 0.2 (beta) - July 9th, 2003
# Copyright 2003 Ketche 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA
#
#######################################################################

# ---------------------------------------------------------------------
# Meta.

VERSION = "0.2"                        # Current PyRunner version.

# ---------------------------------------------------------------------
# Visual.

# Screen size.
SCREENWIDTH = 640
SCREENHEIGHT = 480

# Viewport size.  The viewport is the portion that contains the map
# display.
VIEWWIDTH = 640
VIEWHEIGHT = 440

# Sprite size.  That is, the size of a map object.
SPRITEWIDTH = 16
SPRITEHEIGHT = 20

# The number of animations per frame for players and enemies.
# NOTE:  "frames" are actually moves, whereas "animations" are what
#        should really be called frames.  Unfortunately I used
#        "frames" to mean moves before animation was added so the
#        name has stuck.
ANIMSPERFRAME = 4

# The step amount for smooth animated transitions between squares.
ANIMSTEPX = SPRITEWIDTH / ANIMSPERFRAME
ANIMSTEPY = SPRITEHEIGHT / ANIMSPERFRAME

# The RGB colour used in the sprites to indicate transparency.
# NOTE:  I find this nice blue much easier on the eyes than the ugly
#        purple or other colours that I've seen other games use.
TRANSTUPLE = (64, 128, 192)

# ---------------------------------------------------------------------
# Map

# Map size.
MAPWIDTH = 40
MAPHEIGHT = 22

# Map object IDs.
EMPTY = 0
FLOOR = 1
PERMFLOOR = 2
LADDER = 3
BAR = 4
POLE = 5
GOLD = 6
GATELEFT = 7
GATERIGHT = 8
SWITCH = 9
SPIKES = 10
EXITPOINT = 11

# Hidden map objects.
PLAYERSTART = 100
ENEMYSTART = 101
ENEMYREGEN = 102

# ---------------------------------------------------------------------
# Timing

# The number of squares-per-second the player can move.  Lowering this
# makes the game easier; raising it makes it harder.
MOVEMENTRATE = 10

# The number of frames-per-second we want to run at.  This essentially
# determines the game speed.  (In this case, "frames" refers to screen
# redraws and not our own movement frames.)
TARGETFPS = ANIMSPERFRAME * MOVEMENTRATE

# Tells us how much time (ms) should elapse between frames to meet
# the desired speed.
FRAMEDELAY = 1000 / TARGETFPS

# Time to wait between important keypresses so we don't accidentally
# register a repeat.
KEYLATENCYDELAY = 200

# ---------------------------------------------------------------------
# Movement

# Actions.  These are used as keys in the animation dictionary.
## Could also be used for other things like improving the AI or sending
## actions over a network for a multiplayer version.
ACTIONSTILL = 0
ACTIONLEFT = 1
ACTIONRIGHT = 2
ACTIONUP = 3
ACTIONDOWN = 4
ACTIONDIGLEFT = 5
ACTIONDIGRIGHT = 6
ACTIONSWINGLEFT = 7
ACTIONSWINGRIGHT = 8
ACTIONFALL = 9
ACTIONDEATH = 10
ACTIONSWITCHLEFT = 11
ACTIONSWITCHRIGHT = 12
NUMACTIONS = 13              # Used for ranges.

# Directional constants.  These are used for incremental movement
# by the sprite drawer and also by the Actor module.
DIRNONE = -1
DIRSTART = 0                 # Used for ranges.
DIRLEFT = 0
DIRRIGHT = 1
DIRUP = 2
DIRDOWN = 3
DIREND = 4                   # Used for ranges.

# ---------------------------------------------------------------------
# Scoring

# Normal scores.
GOLDSCORE = 100              # Value of gold.
BONUSGOLDSCORE = 200         # Value of gold if no stages left.
KILLSCORE = 10               # Value of trapping an enemy by digging.

# Costs.
HINTSCORE = -500             # Value (cost) of each hint.

# Bonuses.
LUCKYKILLSCORE = 1           # Bonus if an enemy dies by spikes, etc.
LIFEBONUSSCORE = 50          # Bonus value of each life after a level.
WINGAMESCORE = 1000          # Bonus for completing the last level.
BONUSLIFESCORE = 2000       # Extra life every this-many points.

# ---------------------------------------------------------------------
# Player

# Starting values.
STARTLIVES = 5

# ---------------------------------------------------------------------
# Events

# NOTE:  Delays in this section are expressed in terms of number of
# frames.

# Regeneration events.
FLOORREGENDELAY = 30         # Time it takes for floors to come back.
ENEMYREGENDELAY = 20         # Enemy reincarnation time.

# ---------------------------------------------------------------------
# Enemy Chances

# Maximum chance value.  The chances in this section should be
# expressed as a fraction of this value.  For example, if MAXCHANCE
# is 10000 then a constant of 100 gives a 1% chance.  The proper way
# to test a chance is:
#
# if randrange(MAXCHANCE) < THECHANCE:
#     # Event happens
MAXCHANCE = 10000

ENEMYRANDDROPCHANCE = 100    # Enemy will drop their gold on a whim.
ENEMYJUMPOFFCHANCE = 1000    # Enemy will "smell" the player.
ENEMYSWITCHCHANCE = 5000     # Enemy will pull a switch.

# End of file:  const.py
