#######################################################################
#
# highs.py - The HighScore class.
#
# Defines the information to be stored in the list of high scores.
#
# PyRunner 0.2 (beta) - July 9th, 2003 
# Copyright 2003 Ketche 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA
#
#######################################################################

# Python imports.
import time

# =====================================================================

# Class definitions.

# ---------------------------------------------------------------------
# HighScore - Records a player's performance.
#
class HighScore:
    # Constructor.
    #
    def __init__(self):
        self.name = ""                 # Who.
        self.score = 0                 # What.
        self.level = 0                 # Where.
        self.time = time.time()        # When.
        # Implementation of Why is left as an exercise.  :-)

    # -----------------------------------------------------------------
    # Comparator.
    # Parameters:  other - the object we are being compared with.
    #
    def __cmp__(self, other):
        # We want scores sorted in descending order, so the return
        # values are reversed here.
        if self.score < other.score: return 1
        if self.score > other.score: return -1

        # The first person to make a score gets the higher ranking.
        if self.time < other.time: return -1
        if self.time > other.time: return 1

        return 0

    # -----------------------------------------------------------------
    # String representer.
    # Notes:  Gives us a handy way to get a displayable form of the
    #         record.
    #
    def __str__(self):
        timestr = time.strftime("%m/%d/%y %H:%M:%S", time.localtime(self.time))
        return "%-30s   %07i   %3i   %s" % (self.name, self.score,
                                           self.level, timestr)

# End of file:  highs.py
